ms_occupancy: Theoretical state occupation probabilities

View source: R/simulate.R

ms_occupancyR Documentation

Theoretical state occupation probabilities

Description

Row from of the matrix exponential of Q t at each requested time. Provided so that simulated data can be checked against the process they are supposed to come from.

Usage

ms_occupancy(Q = NULL, times, process = NULL, from = 1L)

Arguments

Q

A generator matrix, or NULL to use process.

times

Numeric vector of times.

process

Character. One of ms_structures().

from

Integer starting state.

Value

A matrix with one row per time and one column per state.

Examples

ms_occupancy(process = "illness_death_3state", times = 0:5)

modMStates documentation built on Sept. 3, 2026, 5:10 p.m.