| ms_generator | R Documentation |
Returns the structurally valid infinitesimal generator for a built-in structure, with the reference intensities used in the package documentation, or the indicator matrix of permitted transitions.
ms_generator(process, rates = NULL)
ms_allowed(process)
process |
Character. One of |
rates |
Optional numeric vector of replacement off-diagonal intensities, in row-major order of the permitted transitions. |
ms_generator returns a square generator matrix with zero row sums.
ms_allowed returns the corresponding matrix of zeros and ones.
ms_generator("illness_death_3state")
ms_allowed("competing_risks")
ms_generator("two_state", rates = 0.35)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.