| ms_occupancy | R Documentation |
Row from of the matrix exponential of Q t at each requested
time. Provided so that simulated data can be checked against the process
they are supposed to come from.
ms_occupancy(Q = NULL, times, process = NULL, from = 1L)
Q |
A generator matrix, or |
times |
Numeric vector of times. |
process |
Character. One of |
from |
Integer starting state. |
A matrix with one row per time and one column per state.
ms_occupancy(process = "illness_death_3state", times = 0:5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.