| ms_structures | R Documentation |
The seven canonical multi-state process structures supported by the package: two-state failure, recurrent event, three-state illness-death, four-state illness-death, reversible illness-death, competing risks and complex hybrid.
ms_structures()
ms_states(process)
process |
Character. One of |
ms_structures returns a character vector of the seven structure names.
ms_states returns the clinical state labels for one structure.
ms_structures()
ms_states("complex_hybrid")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.