| ms_validate_Q | R Documentation |
Checks that a user-supplied generator is square, numeric, finite and has non-negative off-diagonal elements, repairs the diagonal, and reports states that cannot be reached from state one.
ms_validate_Q(Q, strict = FALSE)
Q |
A square numeric matrix of transition intensities. |
strict |
Logical. If |
The validated generator, invisibly, with the diagonal set to minus the row sum of the off-diagonal elements.
ms_validate_Q(rbind(c(0, 0.2, 0.1), c(0, 0, 0.4), c(0, 0, 0)))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.